package com.muyu.engine.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.muyu.engine.domain.RuleEngines;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.engine.domain.RuleEngine;
import com.muyu.engine.domain.req.RuleEngineQueryReq;
import com.muyu.engine.domain.req.RuleEngineSaveReq;
import com.muyu.engine.domain.req.RuleEngineEditReq;
import com.muyu.engine.service.RuleEngineService;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 规则引擎Controller
 *
 * @author muyu
 * @date 2024-05-01
 */
@Api(tags = "规则引擎")
@RestController
@RequestMapping("/engine")
public class RuleEngineController extends BaseController {
    @Autowired
    private RuleEngineService ruleEngineService;

    /**
     * 查询规则引擎列表
     */
    @ApiOperation("获取规则引擎列表")
    @RequiresPermissions("rule_engine:engine:list")
    @GetMapping("/list")
    public Result<TableDataInfo<RuleEngine>> list(RuleEngineQueryReq ruleEngineQueryReq) {
        startPage();
        List<RuleEngine> list = ruleEngineService.list(RuleEngine.queryBuild(ruleEngineQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出规则引擎列表
     */
    @ApiOperation("导出规则引擎列表")
    @RequiresPermissions("rule_engine:engine:export")
    @Log(title = "规则引擎", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RuleEngine ruleEngine) {
        List<RuleEngine> list = ruleEngineService.list(ruleEngine);
        ExcelUtil<RuleEngine> util = new ExcelUtil<RuleEngine>(RuleEngine.class);
        util.exportExcel(response, list, "规则引擎数据");
    }

    /**
     * 获取规则引擎详细信息
     */
    @ApiOperation("获取规则引擎详细信息")
    @RequiresPermissions("rule_engine:engine:query")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<RuleEngine> getInfo(@PathVariable("id") Long id) {
        return Result.success(ruleEngineService.getById(id));
    }

    /**
     * 新增规则引擎
     */
    @RequiresPermissions("rule_engine:engine:add")
    @Log(title = "规则引擎", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增规则引擎")
    public Result add(@RequestBody RuleEngineSaveReq ruleEngineSaveReq) throws Exception {
        ruleEngineService.add(RuleEngine.saveBuild(ruleEngineSaveReq));
        return  Result.success();
    }

    /**
     * 修改规则引擎
     */
    @RequiresPermissions("rule_engine:engine:edit")
    @Log(title = "规则引擎", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改规则引擎")
    public Result<String> edit(@PathVariable Long id, @RequestBody RuleEngineEditReq ruleEngineEditReq) {
        return toAjax(ruleEngineService.updateById(RuleEngine.editBuild(id,ruleEngineEditReq)));
    }

    /**
     * 删除规则引擎
     */
    @RequiresPermissions("rule_engine:engine:remove")
    @Log(title = "规则引擎", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除规则引擎")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        return toAjax(ruleEngineService.removeBatchByIds(ids));
    }


    //编写代码
    @ApiOperation("编写代码")
    @PostMapping("/writeCode")
    public Result code(@RequestBody RuleEngine ruleEngine) throws Exception {
        return Result.success(  ruleEngineService.code(ruleEngine));
    }


    //加载
    @PostMapping("/loading")
    public Result load(@RequestBody RuleEngine ruleEngine) {
        String load = ruleEngineService.load(ruleEngine);
        return Result.success(load);
    }


    @PostMapping("/writeCodeAdd")
    public Result writeCodeAdd(@RequestBody RuleEngines ruleEngine) throws IOException {
        String s = ruleEngineService.writeCodeAdd(ruleEngine);
        return Result.success(s);
    }
    //修改规则引擎是否激活
    @PostMapping("/updateRuleEngineVersionIsActivate")
    public Result updateRuleEngineVersionIsActivate(@RequestBody RuleEngine ruleEngine){
        ruleEngineService.updateRuleEngineVersionIsActivate(ruleEngine);
        return Result.success("引擎激活状态修改成功");
    }    //修改引擎状态
    @PostMapping("/updateRuleEngineVersionStates")
    public Result updateRuleEngineVersionStates(@RequestBody RuleEngine ruleEngine){
        ruleEngineService.updateRuleEngineVersionStates(ruleEngine);
        return Result.success("引擎状态操作成功");
    }
}
